pub struct PlatformBuilder { /* private fields */ }Expand description
Builder type for the OpenThread platform. Create using [Platform::builder()].
Implementations
Sourceimpl PlatformBuilder
impl PlatformBuilder
pub fn thread_netif_index(self, index: u32) -> Self
pub fn backbone_netif_index(self, index: u32) -> Self
Sourcepub fn init<SpinelSink, SpinelStream>(
self,
spinel_sink: SpinelSink,
spinel_stream: SpinelStream,
) -> Platform
pub fn init<SpinelSink, SpinelStream>( self, spinel_sink: SpinelSink, spinel_stream: SpinelStream, ) -> Platform
Initializes the OpenThread platform.
The instance returned by this method must be passed to
ot::Instance::new().
The returned object is a singleton. Attempting to have more than one instance around at a time will cause a panic.